@@ -24,24 +24,30 @@ class JSONSchemaExtractor(Extractor):
     def __init__(
         self,
         connection_name: str,
+        database: str,
     ):
         super().__init__()
         self.connection_name = connection_name
+        self.database = database
 
     def init(self, conf: ConfigTree) -> None:
         self.conf = conf
         self.s3 = boto3.resource("s3")
-        self.database = conf.get_string(self.DATABASE_KEY)
         self.schema_path = conf.get_string(self.SCHEMA_PATH_KEY)
         self.pivot_column = conf.get_string("pivot_column", None)
         self.object_expand = conf.get_list("object_expand", None)
         self.extract_descriptions = conf.get_bool("extract_descriptions", False)
-        self.tags_key = conf.get_string("tags_key", None)
         filter_columns = conf.get_string("filter_columns", None)
         if filter_columns is not None:
             self.filter_columns = re.compile(filter_columns)
         else:
             self.filter_columns = None
+        tags_key = conf.get_string("tags_key", None)
+        if tags_key is not None:
+            self.tags_key = tags_key.split(".")
+        else:
+            self.tags_key = None
+
         self._extract_iter = iter(self._get_extract_iter())
 
     @classmethod
@@ -55,7 +61,7 @@ class JSONSchemaExtractor(Extractor):
             return None
 
     def get_scope(self):
-        return "carte.extractor.json_schema"
+        return f"carte.extractor.json_schema.{self.connection_name}.{self.database}"
 
     def _get_extract_iter(self) -> Iterator[TableMetadata]:
         schema = self._get_schema()
@@ -141,8 +147,11 @@ class JSONSchemaExtractor(Extractor):
             schema.get(self.DESCRIPTION_KEY) if self.extract_descriptions else None
         )
 
-        if self.tags_key:
-            raw_tags = schema.get(self.tags_key, {})
+        if self.tags_key is not None:
+            raw_tags = schema
+
+            for key_segment in self.tags_key:
+                raw_tags = raw_tags.get(key_segment, {})
         else:
             raw_tags = {}
 
